#include <fcntl.h>

#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <ctime>

#include <fstream>
#include <iostream>
#include <string>

using namespace std;

struct Timer
{
  int start;

  Timer() 
  {
    reset();
  }

  double time( int a, int b )
  {
    return (double)(a - b) / CLOCKS_PER_SEC;
  }

  double reset()
  {
    double old = start;
    return time(start = clock(), old);
  }

  double curT()
  {
    return time(clock(), start);
  }

  void wait( double t )
  {
    reset();
    while (curT() < t)
      ;
  }
};

typedef void Function( const char *file );

const int MAX = 4096;
static char buf[MAX];

void F1( const char *file )
{
  FILE *F = fopen(file, "rt");
  while (fscanf(F, "%s", buf) == 1)
    ;
}

void F2( const char *file )
{
  assert(freopen(file, "rt", stdin));
  while (getc(stdin) != -1)
    ;
}

void F3( const char *file )
{
  FILE *F = fopen(file, "rb");
  while ((int)fread(buf, 1, MAX, F) == MAX)
    ;
  fclose(F);
}

void F4( const char *file )
{
  ifstream in(file);
  string s;
  while (in >> s)
    ;
}

void F5( const char *file )
{
  ifstream in(file);
  char c;
  while (in >> c)
    ;
}

void F6( const char *file )
{
  int outFile = open(file, O_RDONLY | O_CREAT);
  while (read(outFile, buf, MAX) == MAX)
    ;
  close(outFile);
}

int main()
{
  Function *F[] = {F1, F2, F3, F4, F5, F6};
  const char *fName[] = {"scanf", "getc", "fread", "fstream_s", "fstream_c", "open"};

  int n = sizeof(F) / sizeof(F[0]);
  int space = 10;
  Timer timer;

  fprintf(stderr, "%*s", space, "value K");
  for (int i = 0; i < n; i++)
    fprintf(stderr, "%*s", space, fName[i]);
  fprintf(stderr, "\n");
   
  for (int k = (int)1e5; k <= (int)1e7; k *= 3)
  {
    fprintf(stderr, "%*d", space, k);
    for (int i = 0; i < n; i++)
    {
      static int no = 0;
      char buf[99];
      sprintf(buf, "out_%02d_%02d", no++, i);

      timer.wait(0.1);
      timer.reset();

      F[i](buf);
      double t = timer.curT();

      fprintf(stderr, "%*.2lf", space, t);
    }
    fprintf(stderr, "\n");
  }
  return 0;
}
                